@@ -48,20 +48,23 @@ def add_basemap(ax,zoom,provider='Stamen',style='TerrainBackground',zorder=0):
 	if provider not in valid_providers:
 		raise ValueError("in add_basemap: provider must be one of %r." % valid_providers)
 	valid_styles = ctx.providers[provider].keys()
-	if style not in valid_styles:
-		raise ValueError("in add_basemap: style must be one of %r." % valid_styles)
-	ctx.add_basemap(ax,zoom=zoom,source=ctx.providers[provider][style],zorder=zorder)
+	if style is not None:
+		if style not in valid_styles:
+			raise ValueError("in add_basemap: style must be one of %r." % valid_styles)
+		ctx.add_basemap(ax,zoom=zoom,source=ctx.providers[provider][style],zorder=zorder)
+	else:
+		ctx.add_basemap(ax,zoom=zoom,source=ctx.providers[provider],zorder=zorder)
 	return ax
 
-def add_stamen_basemap(ax, zoom, stamen='terrain', zorder=0): 
+def add_stamen_basemap(ax, zoom, variant='terrain', zorder=0): 
 	validStamen = {'terrain','background','labels','lines'}
-	if stamen not in validStamen:
+	if variant not in validStamen:
 		raise ValueError("in add_stamen_basemap: stamen must be one of %r." % validStamen)
-	if stamen=='background':
+	if variant=='background':
 		url='http://tile.stamen.com/terrain-background/{z}/{x}/{y}.png'
-	elif stamen=='labels':
+	elif variant=='labels':
 		url='http://tile.stamen.com/terrain-labels/{z}/{x}/{y}.png'
-	elif stamen=='lines':
+	elif variant=='lines':
 		url='http://tile.stamen.com/terrain-lines/{z}/{x}/{y}.png'
 	else:
 		url='http://tile.stamen.com/terrain/{z}/{x}/{y}.png'
